Computes body surface area, used to convert between absolute (mL/min) and BSA-normalised (mL/min/1.73m^2) GFR.
Usage
bsa(weight, height, method = c("dubois", "haycock", "mosteller"))Computes body surface area, used to convert between absolute (mL/min) and BSA-normalised (mL/min/1.73m^2) GFR.
bsa(weight, height, method = c("dubois", "haycock", "mosteller"))