Skip to contents

Arithmetic mean of the EKFC creatinine (egfr_ekfc_cr()) and EKFC cystatin C (egfr_ekfc_cys()) estimates.

Usage

egfr_ekfc_cr_cys(
  creatinine,
  cystatin,
  age,
  sex,
  creatinine_units = "mg/dl",
  label_sex_male = "male",
  label_sex_female = "female",
  q_cr = NULL,
  q_cys = NULL
)

Arguments

creatinine

Numeric vector of serum creatinine.

cystatin

Numeric vector of serum cystatin C in mg/L.

age

Numeric vector of age in years.

sex

Vector of sex labels (see label_sex_male/label_sex_female).

creatinine_units

Units of creatinine: "mg/dl" (default) or "umol/l".

label_sex_male, label_sex_female

Values in sex that denote male and female records. Defaults to "male"/"female".

q_cr

Optional numeric vector of the reference creatinine Q value (median creatinine, in mg/dL) passed to egfr_ekfc_cr(). NULL (default) uses the built-in EKFC reference Q.

q_cys

Optional numeric vector of the reference cystatin C Q value (median cystatin C, in mg/L) passed to egfr_ekfc_cys(). NULL (default) uses the built-in EKFC reference Q.

Value

Numeric vector of eGFR in mL/min/1.73m^2.

References

Pottel H, Bjork J, Rule AD, et al. N Engl J Med. 2023;388(4):333-343. doi:10.1056/NEJMoa2203769

Examples

egfr_ekfc_cr_cys(creatinine = 1.0, cystatin = 0.9, age = 50, sex = "female")
#> [1] 76.67268